@@ -44,19 +44,19 @@ use constant {
     IPV6MIB => 3,
 };
 
-$VERSION = '3.39';
+$VERSION = '3.65';
 
 
 
-%MIBS = ( 
+%MIBS = (
     'IP-MIB'            => 'ipv6InterfaceTableLastChange',
     'IPV6-MIB'          => 'ipv6IfTableLastChange',
-    'CISCO-IETF-IP-MIB' => 'cInetNetToMediaNetAddress', 
+    'CISCO-IETF-IP-MIB' => 'cInetNetToMediaNetAddress',
 );
 
 %GLOBALS = ();
 
-%FUNCS = ( 
+%FUNCS = (
     'ip_n2p_phys_addr'  => 'ipNetToPhysicalPhysAddress',    # IP-MIB
     'c_inet_phys_addr'  => 'cInetNetToMediaPhysAddress',    # CISCO-IETF-IP-MIB
     'i6_n2p_phys_addr'  => 'ipv6NetToMediaPhysAddress',     # IPV6-MIB
@@ -67,20 +67,24 @@ $VERSION = '3.39';
 
     'ip_n2p_phys_state' => 'ipNetToPhysicalState',          # IP-MIB
     'c_inet_phys_state' => 'cInetNetToMediaState',          # CISCO-IETF-IP-MIB
-    'i6_n2p_phys_state' => 'ipv6NetToMediaState',           # IPV6-MIB
+    'i6_n2p_phys_state' => 'ipv6IfNetToMediaState',         # IPV6-MIB
 
     'ip_pfx_origin'     => 'ipAddressPrefixOrigin',         # IP-MIB
-    'c_pfx_origin'      => 'cIpAddressPfxOrigin',           # CISCO-IETF-IP-MIB 
+    'c_pfx_origin'      => 'cIpAddressPfxOrigin',           # CISCO-IETF-IP-MIB
 
-    'ip_addr6_pfx'      => 'ipAddressPrefix',               # IP-MIB 
-    'c_addr6_pfx'       => 'cIpAddressPrefix',              # CISCO-IETF-IP-MIB 
+    'ip_addr6_pfx'      => 'ipAddressPrefix',               # IP-MIB
+    'c_addr6_pfx'       => 'cIpAddressPrefix',              # CISCO-IETF-IP-MIB
+
+    # Commented out are not-accessible according to MIB
+    #'ip_addr6_pfxlen'   => 'ipAddressPrefixLength',        # IP-MIB
+    #'c_addr6_pfxlen'    => 'cIpAddressPfxLength',          # CISCO-IETF-IP-MIB
+    'i6_addr_pfxlen'    => 'ipv6AddrPfxLength',             # IPV6-MIB
 
     'ip_addr6_index'    => 'ipAddressIfIndex',              # IP-MIB
-    'c_addr6_index'     => 'cIpAddressIfIndex',             # CISCO-IETF-IP-MIB 
+    'c_addr6_index'     => 'cIpAddressIfIndex',             # CISCO-IETF-IP-MIB
 
     'ip_addr6_type'     => 'ipAddressType',                 # IP-MIB
     'c_addr6_type'      => 'cIpAddressType',                # CISCO-IETF-IP-MIB
-    
 );
 
 %MUNGE = (
@@ -102,8 +106,8 @@ sub ipv6_n2p_mac {
     foreach my $row (keys %$phys_addr) {
         if ($row =~ /^(\d+)\.(\d+)\.(\d+)\.([\d\.]+)$/) {
             my $ifindex = $1; my $addrtype = $2; my $addrsize = $3; my $v6addr = $4;
-            if ($info::METHOD == IPV6MIB) { 
-                # IPV6-MIB doesn't include the addrtype in the index; 
+            if ($info::METHOD == IPV6MIB) {
+                # IPV6-MIB doesn't include the addrtype in the index;
                 # also, address syntax is IPv6Address (fixed 16 bytes) and not InetAddress (length field followed by address bytes)
                 $v6addr = join('.', $addrtype, $addrsize, $v6addr);
                 $addrtype = 2;
@@ -129,8 +133,8 @@ sub ipv6_n2p_addr {
     foreach my $row (keys %$net_addr) {
         if ($row =~ /^(\d+)\.(\d+)\.(\d+)\.([\d\.]+)$/) {
             my $ifindex = $1; my $addrtype = $2; my $addrsize = $3; my $v6addr = $4;
-            if ($info::METHOD == IPV6MIB) { 
-                # IPV6-MIB doesn't include the addrtype in the index; 
+            if ($info::METHOD == IPV6MIB) {
+                # IPV6-MIB doesn't include the addrtype in the index;
                 # also, address syntax is IPv6Address (fixed 16 bytes) and not InetAddress (length field followed by address bytes)
                 $v6addr = join('.', $addrtype, $addrsize, $v6addr);
                 $addrtype = 2;
@@ -138,7 +142,7 @@ sub ipv6_n2p_addr {
             if ($addrtype == 2) { # IPv6
                 my $v6_packed = pack("C*", split(/\./, $v6addr));
                 if (length($v6_packed) == 15) {
-                    # Workaround for some some IP-MIB implementations, eg on Cisco Nexus: no explicit addrsize, 
+                    # Workaround for some some IP-MIB implementations, eg on Cisco Nexus: no explicit addrsize,
                     # so what we've collected in that variable is actually the first byte of the address.
                     $v6_packed = pack('C', $addrsize) . $v6_packed;
                 }
@@ -173,8 +177,8 @@ sub ipv6_n2p_if {
     foreach my $row (keys %$phys_addr) {
         if ($row =~ /^(\d+)\.(\d+)\.(\d+)\.([\d\.]+)$/) {
             my $ifindex = $1; my $addrtype = $2; my $addrsize = $3; my $v6addr = $4;
-            if ($info::METHOD == IPV6MIB) { 
-                # IPV6-MIB doesn't include the addrtype in the index; 
+            if ($info::METHOD == IPV6MIB) {
+                # IPV6-MIB doesn't include the addrtype in the index;
                 # also, address syntax is IPv6Address (fixed 16 bytes) and not InetAddress (length field followed by address bytes)
                 $v6addr = join('.', $addrtype, $addrsize, $v6addr);
                 $addrtype = 2;
@@ -200,8 +204,8 @@ sub ipv6_n2p_type {
     foreach my $row (keys %$phys_type) {
         if ($row =~ /^(\d+)\.(\d+)\.(\d+)\.([\d\.]+)$/) {
             my $ifindex = $1; my $addrtype = $2; my $addrsize = $3; my $v6addr = $4;
-            if ($info::METHOD == IPV6MIB) { 
-                # IPV6-MIB doesn't include the addrtype in the index; 
+            if ($info::METHOD == IPV6MIB) {
+                # IPV6-MIB doesn't include the addrtype in the index;
                 # also, address syntax is IPv6Address (fixed 16 bytes) and not InetAddress (length field followed by address bytes)
                 $v6addr = join('.', $addrtype, $addrsize, $v6addr);
                 $addrtype = 2;
@@ -227,8 +231,8 @@ sub ipv6_n2p_state {
     foreach my $row (keys %$phys_state) {
         if ($row =~ /^(\d+)\.(\d+)\.(\d+)\.([\d\.]+)$/) {
             my $ifindex = $1; my $addrtype = $2; my $addrsize = $3; my $v6addr = $4;
-            if ($info::METHOD == IPV6MIB) { 
-                # IPV6-MIB doesn't include the addrtype in the index; 
+            if ($info::METHOD == IPV6MIB) {
+                # IPV6-MIB doesn't include the addrtype in the index;
                 # also, address syntax is IPv6Address (fixed 16 bytes) and not InetAddress (length field followed by address bytes)
                 $v6addr = join('.', $addrtype, $addrsize, $v6addr);
                 $addrtype = 2;
@@ -329,6 +333,33 @@ sub ipv6_addr_prefix {
     return $return;
 }
 
+sub ipv6_addr_prefixlength {
+    my $info = shift;
+    my $return;
+    my $ipv6_addr_prefix = &_test_methods( $info, {
+        ip_addr6_pfx  => IPMIB,
+        c_addr6_pfx   => CISCO,
+    });
+    return unless defined $ipv6_addr_prefix;
+    foreach my $row (keys %$ipv6_addr_prefix) {
+        if ($row =~ /^(\d+)\.[\d\.]+$/) {
+            my $type = $1;
+            if (($type == 2) or ($type == 4)) { # IPv6
+                # Remove interface specific part from vrf interfaces
+                if ($row =~ /^((\d+\.){17}\d+)/) { $row = $1 }
+                # Remove the OID part from the value
+                my $val = $ipv6_addr_prefix->{$row};
+                if ( $val =~ /^.+?((?:\d+\.){19}(\d+))$/ ) {
+                    $val = $2;
+                    $return->{$row} = $val;
+                }
+            }
+        }
+    }
+    printf("%s: data comes from %s.\n", &_my_sub_name, $info->_method_used() ) if $info->debug();
+    return $return;
+}
+
 sub ipv6_addr {
     my $info = shift;
     my $return;
@@ -355,6 +386,7 @@ sub ipv6_addr {
 sub _method_used {
     my $info = shift;
     my $return = 'none of the MIBs';
+    # FIXME ugh! a global. makes order of calls important for debug.
     if (defined $info::METHOD) {
         if ($info::METHOD eq IPMIB) {
             $return = 'IP-MIB';
@@ -374,6 +406,7 @@ sub _test_methods {
     foreach my $method (sort {$test->{$a} <=> $test->{$b}} keys %$test) {
         $return = $info->$method || {};
         if (scalar keys %$return) {
+            # FIXME ugh! a global. makes order of calls important for debug.
             $info::METHOD = $test->{$method};
             last;
         }
@@ -409,14 +442,14 @@ Jeroen van Ingen and Carlos Vicente
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $info = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $info->class();
@@ -424,12 +457,12 @@ Jeroen van Ingen and Carlos Vicente
 
 =head1 DESCRIPTION
 
-The SNMP::Info::IPv6 class implements functions to for mapping IPv6 addresses 
+The SNMP::Info::IPv6 class implements functions to for mapping IPv6 addresses
 to MAC addresses, interfaces and more. It will use data from the F<IP-MIB>,
 F<IPV6-MIB>, or the F<CISCO-IETF-IP-MIB>, whichever is supported by the
 device.
 
-This class is inherited by Info::Layer3 to provide IPv6 node tracking across  
+This class is inherited by Info::Layer3 to provide IPv6 node tracking across
 device classes.
 
 For debugging purposes you can call this class directly as you would
@@ -486,10 +519,14 @@ Maps an IPv6 address to its type (unicast, anycast, etc.)
 
 Maps an IPv6 prefix with its origin (manual, well-known, dhcp, etc.)
 
-=item $info->ipv6_addr_prefix() 
+=item $info->ipv6_addr_prefix()
 
 Maps IPv6 addresses with their prefixes
 
+=item $info->ipv6_addr_prefixlength()
+
+Maps IPv6 addresses with their prefix length
+
 =item $info->ipv6_addr()
 
 Maps a table instance to an IPv6 address
@@ -508,7 +545,7 @@ Maps an address of type C<cInetNetToMediaNetAddressType> on interface C<ifIndex>
 
 =head1 MUNGES
 
-=over 
+=over
 
 =item munge_physaddr()
 
